@@ -1,4 +1,5 @@
 import { OrgRole } from '@grafana/data';
+import { t } from '@grafana/i18n';
 import { Select } from '@grafana/ui';
 
 interface Props {
@@ -21,7 +22,7 @@ export function OrgRolePicker({ value, onChange, 'aria-label': ariaLabel, inputI
       value={value}
       options={options}
       onChange={(val) => onChange(val.value ?? OrgRole.None)}
-      placeholder="Choose role..."
+      placeholder={t('admin.org-role-picker.placeholder-choose-role', 'Choose role...')}
       aria-label={ariaLabel}
       autoFocus={autoFocus}
       {...restProps}
