@@ -3,11 +3,15 @@ import { connect, ConnectedProps } from 'react-redux';
 import { useParams } from 'react-router-dom-v5-compat';
 
 import { NavModelItem } from '@grafana/data';
+import { t } from '@grafana/i18n';
 import { featureEnabled } from '@grafana/runtime';
 import { Stack } from '@grafana/ui';
 import { Page } from 'app/core/components/Page/Page';
 import { contextSrv } from 'app/core/core';
-import { StoreState, UserDTO, UserOrg, UserSession, SyncInfo, UserAdminError, AccessControlAction } from 'app/types';
+import { AccessControlAction } from 'app/types/accessControl';
+import { SyncInfo } from 'app/types/ldap';
+import { StoreState } from 'app/types/store';
+import { UserDTO, UserOrg, UserSession, UserAdminError } from 'app/types/user';
 
 import { UserLdapSyncInfo } from './UserLdapSyncInfo';
 import { UserOrgs } from './UserOrgs';
@@ -115,12 +119,18 @@ export const UserAdminPage = ({
   const isLDAPUser = user?.isExternal && user?.authLabels?.includes('LDAP');
   const canReadSessions = contextSrv.hasPermission(AccessControlAction.UsersAuthTokenList);
   const canReadLDAPStatus = contextSrv.hasPermission(AccessControlAction.LDAPStatusRead);
-  const authSource = user?.authLabels?.[0];
+  let authSource = user?.authLabels?.[0];
+  if (user?.isProvisioned) {
+    authSource = 'SCIM';
+  }
   const lockMessage = authSource ? `Synced via ${authSource}` : '';
   const pageNav: NavModelItem = {
     text: user?.login ?? '',
     icon: 'shield',
-    subTitle: 'Manage settings for an individual user.',
+    subTitle: t(
+      'admin.user-admin-page.page-nav.subTitle.manage-settings-for-an-individual-user',
+      'Manage settings for an individual user.'
+    ),
   };
 
   return (
