@@ -3,7 +3,6 @@ import { css, cx } from '@emotion/css';
 import { GrafanaTheme2 } from '@grafana/data';
 import { selectors as e2eSelectors } from '@grafana/e2e-selectors/src';
 import { Trans, t } from '@grafana/i18n';
-import { config } from '@grafana/runtime';
 import { Button, LoadingPlaceholder, Modal, ModalsController, useStyles2 } from '@grafana/ui';
 import {
   generatePublicDashboardConfigUrl,
@@ -22,11 +21,7 @@ export const DashboardsListModal = ({ email, onDismiss }: { email: string; onDis
     <Modal
       className={styles.modal}
       isOpen
-      title={
-        config.featureToggles.newDashboardSharingComponent
-          ? t('public-dashboard-users-access-list.modal.shared-dashboard-modal-title', 'Shared dashboards')
-          : t('public-dashboard-users-access-list.modal.dashboard-modal-title', 'Public dashboards')
-      }
+      title={t('public-dashboard-users-access-list.modal.shared-dashboard-modal-title', 'Shared dashboards')}
       onDismiss={onDismiss}
     >
       {isLoading ? (
@@ -47,15 +42,7 @@ export const DashboardsListModal = ({ email, onDismiss }: { email: string; onDis
                 href={generatePublicDashboardUrl(dash.publicDashboardAccessToken)}
                 onClick={onDismiss}
               >
-                {config.featureToggles.newDashboardSharingComponent ? (
-                  <Trans i18nKey="public-dashboard-users-access-list.dashboard-modal.external-link">
-                    External link
-                  </Trans>
-                ) : (
-                  <Trans i18nKey="public-dashboard-users-access-list.dashboard-modal.public-dashboard-link">
-                    Public dashboard URL
-                  </Trans>
-                )}
+                <Trans i18nKey="public-dashboard-users-access-list.dashboard-modal.external-link">External link</Trans>
               </a>
               <span className={styles.urlsDivider}>{'•'}</span>
               <a
@@ -63,15 +50,9 @@ export const DashboardsListModal = ({ email, onDismiss }: { email: string; onDis
                 href={generatePublicDashboardConfigUrl(dash.dashboardUid, dash.slug)}
                 onClick={onDismiss}
               >
-                {config.featureToggles.newDashboardSharingComponent ? (
-                  <Trans i18nKey="public-dashboard-users-access-list.dashboard-modal.sharing-setting">
-                    Sharing settings
-                  </Trans>
-                ) : (
-                  <Trans i18nKey="public-dashboard-users-access-list.dashboard-modal.public-dashboard-setting">
-                    Public dashboard settings
-                  </Trans>
-                )}
+                <Trans i18nKey="public-dashboard-users-access-list.dashboard-modal.sharing-setting">
+                  Sharing settings
+                </Trans>
               </a>
             </div>
             <hr className={styles.divider} />
