@@ -32,12 +32,12 @@ import { GrafanaQueryType } from 'app/plugins/datasource/grafana/types';
 
 import { DashboardDataLayerSet } from '../scene/DashboardDataLayerSet';
 import { DashboardScene } from '../scene/DashboardScene';
-import { PanelTimeRange } from '../scene/PanelTimeRange';
 import { DashboardGridItem } from '../scene/layout-default/DashboardGridItem';
 import { DefaultGridLayoutManager } from '../scene/layout-default/DefaultGridLayoutManager';
 import { RowRepeaterBehavior } from '../scene/layout-default/RowRepeaterBehavior';
-import { isClonedKey } from '../utils/clone';
+import { PanelTimeRange } from '../scene/panel-timerange/PanelTimeRange';
 import { dashboardSceneGraph } from '../utils/dashboardSceneGraph';
+import { djb2Hash } from '../utils/djb2Hash';
 import {
   calculateGridItemDimensions,
   getLibraryPanelBehavior,
@@ -73,9 +73,10 @@ export function transformSceneToSaveModel(scene: DashboardScene, isSnapshot = fa
 
       if (child instanceof SceneGridRow) {
         // Skip repeat clones or when generating a snapshot
-        if (isClonedKey(child.state.key!) && !isSnapshot) {
+        if (child.state.repeatSourceKey && !isSnapshot) {
           continue;
         }
+
         gridRowToSaveModel(child, panels, isSnapshot);
       }
     }
@@ -231,6 +232,7 @@ export function vizPanelToPanel(
     panel.timeFrom = panelTime.state.timeFrom;
     panel.timeShift = panelTime.state.timeShift;
     panel.hideTimeOverride = panelTime.state.hideTimeOverride;
+    panel.timeCompare = panelTime.state.compareWith;
   }
 
   if (gridItem instanceof DashboardGridItem) {
@@ -329,48 +331,46 @@ export function panelRepeaterToPanels(repeater: DashboardGridItem, isSnapshot =
       return [vizPanelToPanel(repeater.state.body, { x, y, w, h }, isSnapshot)];
     }
 
-    if (repeater.state.repeatedPanels) {
-      const { h, w, columnCount } = calculateGridItemDimensions(repeater);
-      const panels = repeater.state.repeatedPanels!.map((panel, index) => {
-        let x = 0,
-          y = 0;
-        if (repeater.state.repeatDirection === 'v') {
-          x = repeater.state.x!;
-          y = index * h;
-        } else {
-          x = (index % columnCount) * w;
-          y = repeater.state.y! + Math.floor(index / columnCount) * h;
-        }
+    const vizPanels = [repeater.state.body, ...(repeater.state.repeatedPanels ?? [])];
 
-        const gridPos = { x, y, w, h };
+    const { h, w, columnCount } = calculateGridItemDimensions(repeater);
+    const panels = vizPanels.map((panel, index) => {
+      let x = 0,
+        y = 0;
+      if (repeater.state.repeatDirection === 'v') {
+        x = repeater.state.x!;
+        y = repeater.state.y! + index * h;
+      } else {
+        x = (index % columnCount) * w;
+        y = repeater.state.y! + Math.floor(index / columnCount) * h;
+      }
 
-        const localVariable = panel.state.$variables!.getByName(repeater.state.variableName!) as LocalValueVariable;
+      const gridPos = { x, y, w, h };
 
-        const result: Panel = {
-          id: getPanelIdForVizPanel(panel),
-          type: panel.state.pluginId,
-          title: panel.state.title,
-          gridPos,
-          options: panel.state.options,
-          fieldConfig: (panel.state.fieldConfig as FieldConfigSource) ?? { defaults: {}, overrides: [] },
-          transformations: [],
-          transparent: panel.state.displayMode === 'transparent',
-          // @ts-expect-error scopedVars are runtime only properties, not part of the persisted Dashboardmodel
-          scopedVars: {
-            [repeater.state.variableName!]: {
-              text: localVariable?.state.text,
-              value: localVariable?.state.value,
-            },
+      const localVariable = panel.state.$variables!.getByName(repeater.state.variableName!) as LocalValueVariable;
+
+      const result: Panel = {
+        id: djb2Hash(panel.state.key!),
+        type: panel.state.pluginId,
+        title: panel.state.title,
+        gridPos,
+        options: panel.state.options,
+        fieldConfig: (panel.state.fieldConfig as FieldConfigSource) ?? { defaults: {}, overrides: [] },
+        transformations: [],
+        transparent: panel.state.displayMode === 'transparent',
+        // @ts-expect-error scopedVars are runtime only properties, not part of the persisted Dashboardmodel
+        scopedVars: {
+          [repeater.state.variableName!]: {
+            text: localVariable?.state.text,
+            value: localVariable?.state.value,
           },
-          ...vizPanelDataToPanel(panel, isSnapshot),
-        };
-        return result;
-      });
+        },
+        ...vizPanelDataToPanel(panel, isSnapshot),
+      };
+      return result;
+    });
 
-      return panels;
-    }
-
-    return [];
+    return panels;
   }
 }
 
