@@ -4,7 +4,7 @@ import { connect, ConnectedProps } from 'react-redux';
 
 import { NavModel, NavModelItem, TimeRange, PageLayoutType, locationUtil, GrafanaTheme2 } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
-import { config, locationService } from '@grafana/runtime';
+import { locationService } from '@grafana/runtime';
 import { Themeable2, withTheme2 } from '@grafana/ui';
 import { notifyApp } from 'app/core/actions';
 import { ScrollRefElement } from 'app/core/components/NativeScrollbar';
@@ -17,17 +17,16 @@ import { ID_PREFIX } from 'app/core/reducers/navBarTree';
 import { getNavModel } from 'app/core/selectors/navModel';
 import { PanelModel } from 'app/features/dashboard/state/PanelModel';
 import { dashboardWatcher } from 'app/features/live/dashboard/dashboardWatcher';
-import { AngularDeprecationNotice } from 'app/features/plugins/angularDeprecation/AngularDeprecationNotice';
-import { AngularMigrationNotice } from 'app/features/plugins/angularDeprecation/AngularMigrationNotice';
-import { KioskMode, StoreState } from 'app/types';
+import { KioskMode } from 'app/types/dashboard';
 import { PanelEditEnteredEvent, PanelEditExitedEvent } from 'app/types/events';
+import { StoreState } from 'app/types/store';
 
 import { cancelVariables, templateVarsChangedInUrl } from '../../variables/state/actions';
 import { findTemplateVarChanges } from '../../variables/utils';
-import { DashNav } from '../components/DashNav';
+import DashNav from '../components/DashNav/DashNav';
 import { DashboardLoading } from '../components/DashboardLoading/DashboardLoading';
 import { DashboardPrompt } from '../components/DashboardPrompt/DashboardPrompt';
-import { DashboardSettings } from '../components/DashboardSettings';
+import { DashboardSettings } from '../components/DashboardSettings/DashboardSettings';
 import { PanelInspector } from '../components/Inspector/PanelInspector';
 import { PanelEditor } from '../components/PanelEditor/PanelEditor';
 import { ShareModal } from '../components/ShareModal/ShareModal';
@@ -35,7 +34,6 @@ import { SubMenu } from '../components/SubMenu/SubMenu';
 import { DashboardGrid } from '../dashgrid/DashboardGrid';
 import { liveTimer } from '../dashgrid/liveTimer';
 import { getTimeSrv } from '../services/TimeSrv';
-import { explicitlyControlledMigrationPanels, autoMigrateAngular } from '../state/PanelModel';
 import { cleanUpDashboardAndVariables } from '../state/actions';
 import { initDashboard } from '../state/initDashboard';
 
@@ -86,10 +84,12 @@ const getStyles = (theme: GrafanaTheme2) => ({
   fullScreenPanel: css({
     '.react-grid-layout': {
       height: 'auto !important',
+      // eslint-disable-next-line @grafana/no-unreduced-motion
       transitionProperty: 'none',
     },
     '.react-grid-item': {
       display: 'none !important',
+      // eslint-disable-next-line @grafana/no-unreduced-motion
       transitionProperty: 'none !important',
 
       '&--fullscreen': {
@@ -374,50 +374,6 @@ export class UnthemedDashboardPage extends PureComponent<Props, State> {
       'page-hidden': Boolean(queryParams.editview || editPanel),
     });
 
-    const migrationFeatureFlags = new Set([
-      'autoMigrateOldPanels',
-      'autoMigrateGraphPanel',
-      'autoMigrateTablePanel',
-      'autoMigratePiechartPanel',
-      'autoMigrateWorldmapPanel',
-      'autoMigrateStatPanel',
-      'disableAngular',
-    ]);
-
-    const isAutoMigrationFlagSet = () => {
-      const urlParams = new URLSearchParams(window.location.search);
-      let isFeatureFlagSet = false;
-
-      urlParams.forEach((value, key) => {
-        if (key.startsWith('__feature.')) {
-          const featureName = key.substring(10);
-          const toggleState = value === 'true' || value === '';
-          const featureToggles = config.featureToggles as Record<string, boolean>;
-
-          if (featureToggles[featureName]) {
-            return;
-          }
-
-          if (migrationFeatureFlags.has(featureName) && toggleState) {
-            isFeatureFlagSet = true;
-            return;
-          }
-        }
-      });
-
-      return isFeatureFlagSet;
-    };
-
-    const dashboardWasAngular = dashboard.panels.some(
-      (panel) => panel.autoMigrateFrom && autoMigrateAngular[panel.autoMigrateFrom] != null
-    );
-
-    const showDashboardMigrationNotice =
-      config.featureToggles.angularDeprecationUI &&
-      dashboardWasAngular &&
-      isAutoMigrationFlagSet() &&
-      dashboard.uid !== null;
-
     return (
       <>
         <Page
@@ -446,15 +402,6 @@ export class UnthemedDashboardPage extends PureComponent<Props, State> {
               <SubMenu dashboard={dashboard} annotations={dashboard.annotations.list} links={dashboard.links} />
             </section>
           )}
-          {config.featureToggles.angularDeprecationUI && dashboard.hasAngularPlugins() && dashboard.uid !== null && (
-            <AngularDeprecationNotice
-              dashboardUid={dashboard.uid}
-              showAutoMigrateLink={dashboard.panels.some((panel) =>
-                explicitlyControlledMigrationPanels.includes(panel.type)
-              )}
-            />
-          )}
-          {showDashboardMigrationNotice && <AngularMigrationNotice dashboardUid={dashboard.uid} />}
           {!initError && (
             <DashboardGrid
               dashboard={dashboard}
