@@ -12,9 +12,8 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-import { css } from '@emotion/css';
+import { css, cx } from '@emotion/css';
 import { SpanStatusCode } from '@opentelemetry/api';
-import cx from 'classnames';
 import { useCallback, useMemo } from 'react';
 
 import {
@@ -28,12 +27,13 @@ import {
   TraceLog,
   PluginExtensionResourceAttributesContext,
   PluginExtensionPoints,
+  IconName,
 } from '@grafana/data';
-import { Trans, t } from '@grafana/i18n';
+import { t } from '@grafana/i18n';
 import { TraceToProfilesOptions } from '@grafana/o11y-ds-frontend';
 import { usePluginLinks } from '@grafana/runtime';
 import { TimeZone } from '@grafana/schema';
-import { Divider, Icon, TextArea, useStyles2 } from '@grafana/ui';
+import { Icon, useStyles2 } from '@grafana/ui';
 
 import { pyroscopeProfileIdTagKey } from '../../../createSpanLink';
 import { autoColor } from '../../Theme';
@@ -41,17 +41,29 @@ import LabeledList from '../../common/LabeledList';
 import { KIND, LIBRARY_NAME, LIBRARY_VERSION, STATUS, STATUS_MESSAGE, TRACE_STATE } from '../../constants/span';
 import { SpanLinkFunc } from '../../types/links';
 import { TraceProcess, TraceSpan, TraceSpanReference } from '../../types/trace';
-import { formatDuration } from '../utils';
+import { formatDuration } from '../../utils/date';
 
 import AccordianKeyValues from './AccordianKeyValues';
 import AccordianLogs from './AccordianLogs';
 import AccordianReferences from './AccordianReferences';
-import AccordianText from './AccordianText';
 import DetailState from './DetailState';
+import { ShareSpanButton } from './ShareSpanButton';
 import { getSpanDetailLinkButtons } from './SpanDetailLinkButtons';
 import SpanFlameGraph from './SpanFlameGraph';
 
-const useResourceAttributesExtensionLinks = (process: TraceProcess, datasourceType: string, datasourceUid: string) => {
+const useResourceAttributesExtensionLinks = ({
+  process,
+  spanTags,
+  datasourceType,
+  datasourceUid,
+  timeRange,
+}: {
+  process: TraceProcess;
+  spanTags: TraceKeyValuePair[];
+  datasourceType: string;
+  datasourceUid: string;
+  timeRange: TimeRange;
+}) => {
   // Stable context for useMemo inside usePluginLinks
   const context: PluginExtensionResourceAttributesContext = useMemo(() => {
     const attributes = (process.tags ?? []).reduce<Record<string, string[]>>((acc, tag) => {
@@ -63,14 +75,25 @@ const useResourceAttributesExtensionLinks = (process: TraceProcess, datasourceTy
       return acc;
     }, {});
 
+    const spanAttributes = (spanTags ?? []).reduce<Record<string, string[]>>((acc, tag) => {
+      if (acc[tag.key]) {
+        acc[tag.key].push(tag.value);
+      } else {
+        acc[tag.key] = [tag.value];
+      }
+      return acc;
+    }, {});
+
     return {
       attributes,
+      spanAttributes,
+      timeRange: { from: timeRange.from.valueOf(), to: timeRange.to.valueOf() },
       datasource: {
         type: datasourceType,
         uid: datasourceUid,
       },
     };
-  }, [process.tags, datasourceType, datasourceUid]);
+  }, [process.tags, spanTags, datasourceType, datasourceUid, timeRange]);
 
   const { links } = usePluginLinks({
     extensionPointId: PluginExtensionPoints.TraceViewResourceAttributes,
@@ -98,45 +121,27 @@ const getStyles = (theme: GrafanaTheme2) => {
       gap: '0 1rem',
       marginBottom: '0.25rem',
     }),
+    content: css({
+      fontSize: theme.typography.bodySmall.fontSize,
+    }),
     listWrapper: css({
       overflow: 'hidden',
+      flexGrow: 1,
+      display: 'flex',
+      justifyContent: 'flex-end',
     }),
     list: css({
-      textAlign: 'right',
+      textAlign: 'left',
     }),
     operationName: css({
       margin: 0,
       overflow: 'hidden',
       textOverflow: 'ellipsis',
       whiteSpace: 'nowrap',
-      flexBasis: '50%',
+      maxWidth: '50%',
       flexGrow: 0,
       flexShrink: 0,
     }),
-    debugInfo: css({
-      label: 'debugInfo',
-      display: 'block',
-      letterSpacing: '0.25px',
-      margin: '0.5em 0 -0.75em',
-      textAlign: 'right',
-    }),
-    debugLabel: css({
-      label: 'debugLabel',
-      '&::before': {
-        color: autoColor(theme, '#bbb'),
-        content: 'attr(data-label)',
-      },
-    }),
-    debugValue: css({
-      label: 'debugValue',
-      backgroundColor: 'inherit',
-      border: 'none',
-      color: autoColor(theme, '#888'),
-      cursor: 'pointer',
-      '&:hover': {
-        color: autoColor(theme, '#333'),
-      },
-    }),
     AccordianWarnings: css({
       label: 'AccordianWarnings',
       background: autoColor(theme, '#fafafa'),
@@ -159,20 +164,32 @@ const getStyles = (theme: GrafanaTheme2) => {
       label: 'AccordianWarningsLabel',
       color: autoColor(theme, '#d36c08'),
     }),
-    AccordianKeyValuesItem: css({
-      marginBottom: theme.spacing(0.5),
-    }),
     Textarea: css({
       wordBreak: 'break-all',
       whiteSpace: 'pre',
     }),
-    LinkIcon: css({
-      fontSize: '1.5em',
-    }),
     linkList: css({
       display: 'flex',
       flexWrap: 'wrap',
       gap: '10px',
+      marginBottom: theme.spacing(2),
+    }),
+    debugInfo: css({
+      label: 'debugInfo',
+      display: 'block',
+      letterSpacing: '0.25px',
+      margin: '0.5em 0 -0.75em',
+      textAlign: 'right',
+    }),
+    debugLabel: css({
+      label: 'debugLabel',
+      '&::before': {
+        color: autoColor(theme, '#bbb'),
+        content: 'attr(data-label)',
+      },
+    }),
+    LinkIcon: css({
+      fontSize: '1.5em',
     }),
   };
 };
@@ -186,6 +203,7 @@ export type TraceFlameGraphs = {
 };
 
 export type SpanDetailProps = {
+  color: string;
   detailState: DetailState;
   logItemToggle: (spanID: string, log: TraceLog) => void;
   logsToggle: (spanID: string) => void;
@@ -215,6 +233,7 @@ export type SpanDetailProps = {
 
 export default function SpanDetail(props: SpanDetailProps) {
   const {
+    color,
     detailState,
     logItemToggle,
     logsToggle,
@@ -263,6 +282,9 @@ export default function SpanDetail(props: SpanDetailProps) {
   } = span;
 
   const { timeZone } = props;
+  const durationIcon: IconName = 'hourglass';
+  const startIcon: IconName = 'clock-nine';
+
   let overviewItems = [
     {
       key: 'svc',
@@ -273,11 +295,13 @@ export default function SpanDetail(props: SpanDetailProps) {
       key: 'duration',
       label: t('explore.span-detail.overview-items.label.duration', 'Duration:'),
       value: formatDuration(duration),
+      icon: durationIcon,
     },
     {
       key: 'start',
       label: t('explore.span-detail.overview-items.label.start-time', 'Start Time:'),
       value: formatDuration(relativeStartTime) + getAbsoluteTime(startTime, timeZone),
+      icon: startIcon,
     },
     ...(span.childSpanCount > 0
       ? [
@@ -343,32 +367,38 @@ export default function SpanDetail(props: SpanDetailProps) {
     app,
   });
 
-  const focusSpanLink = createFocusSpanLink(traceID, spanID);
-  const resourceLinksGetter = useResourceAttributesExtensionLinks(process, datasourceType, datasourceUid);
+  const { interpolatedParams, ...focusSpanLink } = createFocusSpanLink(traceID, spanID);
+  const resourceLinksGetter = useResourceAttributesExtensionLinks({
+    process,
+    spanTags: tags,
+    datasourceType,
+    datasourceUid,
+    timeRange,
+  });
 
   return (
     <div data-testid="span-detail-component">
       <div className={styles.header}>
-        <h2 className={styles.operationName} title={operationName}>
+        <h6 className={styles.operationName} title={operationName}>
           {operationName}
-        </h2>
+        </h6>
         <div className={styles.listWrapper}>
-          <LabeledList className={styles.list} divider={true} items={overviewItems} />
+          <LabeledList className={styles.list} divider={false} items={overviewItems} color={color} />
         </div>
+        <ShareSpanButton focusSpanLink={focusSpanLink} />
       </div>
       <div className={styles.linkList}>{linksComponent}</div>
-      <Divider spacing={1} />
-      <div>
+      <div className={styles.content}>
         <div>
           <AccordianKeyValues
             data={tags}
             label={t('explore.span-detail.label-span-attributes', 'Span attributes')}
             isOpen={isTagsOpen}
+            linksGetter={resourceLinksGetter}
             onToggle={() => tagsToggle(spanID)}
           />
           {process.tags && (
             <AccordianKeyValues
-              className={styles.AccordianKeyValuesItem}
               data={process.tags}
               label={t('explore.span-detail.label-resource-attributes', 'Resource attributes')}
               linksGetter={resourceLinksGetter}
@@ -387,48 +417,39 @@ export default function SpanDetail(props: SpanDetailProps) {
             timestamp={traceStartTime}
           />
         )}
+
         {warnings && warnings.length > 0 && (
-          <AccordianText
-            className={styles.AccordianWarnings}
-            headerClassName={styles.AccordianWarningsHeader}
-            label={
-              <span className={styles.AccordianWarningsLabel}>
-                <Trans i18nKey="explore.span-detail.warnings">Warnings</Trans>
-              </span>
-            }
-            data={warnings}
+          <AccordianKeyValues
+            data={warnings.map((warning) => ({
+              key: '',
+              value: warning,
+              type: 'text',
+            }))}
+            showSummary={false}
+            showCountBadge={true}
             isOpen={isWarningsOpen}
+            onlyValues={true}
             onToggle={() => warningsToggle(spanID)}
+            label={t('explore.span-detail.warnings', 'Warnings')}
           />
         )}
+
         {stackTraces?.length ? (
-          <AccordianText
-            label={t('explore.span-detail.label-stack-trace', 'Stack trace')}
-            data={stackTraces}
+          <AccordianKeyValues
+            data={stackTraces.map((stackTrace) => ({
+              key: '',
+              value: stackTrace,
+              type: 'code',
+            }))}
+            onlyValues={true}
+            showSummary={false}
+            showCountBadge={true}
             isOpen={isStackTracesOpen}
-            TextComponent={(textComponentProps) => {
-              let text;
-              if (textComponentProps.data?.length > 1) {
-                text = textComponentProps.data
-                  .map((stackTrace, index) => `StackTrace ${index + 1}:\n${stackTrace}`)
-                  .join('\n');
-              } else {
-                text = textComponentProps.data?.[0];
-              }
-              return (
-                <TextArea
-                  className={styles.Textarea}
-                  style={{ cursor: 'unset' }}
-                  readOnly
-                  cols={10}
-                  rows={10}
-                  value={text}
-                />
-              );
-            }}
             onToggle={() => stackTracesToggle(spanID)}
+            label={t('explore.span-detail.label-stack-trace', 'Stack trace')}
           />
         ) : null}
+
         {references && references.length > 0 && (references.length > 1 || references[0].refType !== 'CHILD_OF') && (
           <AccordianReferences
             data={references}
@@ -451,6 +472,7 @@ export default function SpanDetail(props: SpanDetailProps) {
             traceName={traceName}
           />
         )}
+
         <small className={styles.debugInfo}>
           {/* TODO: fix keyboard a11y */}
           {/* eslint-disable-next-line jsx-a11y/click-events-have-key-events, jsx-a11y/no-static-element-interactions */}
