@@ -29,7 +29,7 @@ import { SpanLinkFunc } from '../types/links';
 import { TraceSpan, Trace, TraceSpanReference, CriticalPathSection } from '../types/trace';
 
 import { TraceFlameGraphs } from './SpanDetail';
-import TimelineHeaderRow from './TimelineHeaderRow';
+import TimelineHeaderRow from './TimelineHeaderRow/TimelineHeaderRow';
 import VirtualizedTraceView from './VirtualizedTraceView';
 import { TUpdateViewRangeTimeFunction, ViewRange, ViewRangeTimeUpdate } from './types';
 
@@ -40,7 +40,6 @@ const getStyles = stylesFactory((theme: GrafanaTheme2) => ({
 
     '& .json-markup': {
       lineHeight: '17px',
-      fontSize: '13px',
       fontFamily: 'monospace',
       whiteSpace: 'pre-wrap',
     },
