@@ -6,6 +6,6 @@ import { searchCompleted } from './reducer';
 export function getConnectedDashboards(libraryPanel: LibraryElementDTO): DispatchResult {
   return async function (dispatch) {
     const dashboards = await apiGetConnectedDashboards(libraryPanel.uid);
-    dispatch(searchCompleted({ dashboards }));
+    dispatch(searchCompleted({ dashboards: dashboards || [] }));
   };
 }
