@@ -5,7 +5,8 @@ import { Subject } from 'rxjs';
 // Importing this way to be able to spy on grafana/data
 
 import * as grafanaData from '@grafana/data';
-import { DataSourceApi, dateTime, TypedVariableModel } from '@grafana/data';
+import { DataSourceApi, DataTransformerID, dateTime, TypedVariableModel } from '@grafana/data';
+import { FrameType, mockTransformationsRegistry } from '@grafana/data/internal';
 import { DataSourceSrv, setDataSourceSrv, setEchoSrv } from '@grafana/runtime';
 import { TemplateSrvMock } from 'app/features/templating/template_srv.mock';
 
@@ -181,6 +182,11 @@ function describeQueryRunnerScenario(
 }
 
 describe('PanelQueryRunner', () => {
+  beforeAll(() => {
+    const { convertFrameTypeTransformer } = grafanaData.standardTransformers;
+    mockTransformationsRegistry([convertFrameTypeTransformer]);
+  });
+
   beforeEach(() => {
     jest.clearAllMocks();
   });
@@ -319,6 +325,48 @@ describe('PanelQueryRunner', () => {
     }
   );
 
+  describeQueryRunnerScenario(
+    'transformations',
+    (ctx) => {
+      it('should re-categorize any anno frames returned by series transformations', async () => {
+        ctx.runner.getData({ withTransforms: true, withFieldConfig: false }).subscribe({
+          next: (data: grafanaData.PanelData) => {
+            try {
+              expect(data.series).toEqual([]);
+              expect(data.annotations).toEqual([
+                {
+                  name: 'exemplar',
+                  meta: { custom: { resultType: 'exemplar' }, dataTopic: 'annotations' },
+                  length: 2,
+                  fields: [
+                    { config: {}, name: 'Time', state: null, type: 'time', values: [1000, 2000] },
+                    { config: {}, name: 'Value', state: null, type: 'number', values: [1, 2] },
+                  ],
+                },
+              ]);
+              return data;
+            } catch (e) {
+              return Promise.reject(e instanceof Error ? e.message : e);
+            }
+          },
+        });
+      });
+    },
+    {
+      getFieldOverrideOptions: () => undefined,
+      getTransformations: () => [
+        {
+          id: DataTransformerID.convertFrameType,
+          topic: grafanaData.DataTopic.Series,
+          options: {
+            targetType: FrameType.Exemplar,
+          },
+        },
+      ],
+      getDataSupport: () => ({ annotations: true, alertStates: false }),
+    }
+  );
+
   describeQueryRunnerScenario(
     'getData',
     (ctx) => {
