@@ -1,27 +1,22 @@
-import { css } from '@emotion/css';
 import { debounce } from 'lodash';
 import { useCallback, useMemo, useState } from 'react';
 import { useEffectOnce } from 'react-use';
 
 import { CoreApp, QueryEditorProps } from '@grafana/data';
-import { config, reportInteraction } from '@grafana/runtime';
-import { Alert, Button, CodeEditor, Space } from '@grafana/ui';
+import { Trans, t } from '@grafana/i18n';
+import { config } from '@grafana/runtime';
+import { Alert, CodeEditor, Space, TextLink } from '@grafana/ui';
 
 import AzureMonitorDatasource from '../../datasource';
 import { selectors } from '../../e2e/selectors';
-import {
-  AzureMonitorDataSourceJsonData,
-  AzureMonitorErrorish,
-  AzureMonitorOption,
-  AzureMonitorQuery,
-  AzureQueryType,
-} from '../../types';
+import { AzureMonitorQuery, AzureQueryType } from '../../types/query';
+import { AzureMonitorDataSourceJsonData, AzureMonitorErrorish, AzureMonitorOption } from '../../types/types';
 import useLastError from '../../utils/useLastError';
-import ArgQueryEditor from '../ArgQueryEditor';
-import LogsQueryEditor from '../LogsQueryEditor';
+import ArgQueryEditor from '../ArgQueryEditor/ArgQueryEditor';
 import { AzureCheatSheetModal } from '../LogsQueryEditor/AzureCheatSheetModal';
+import LogsQueryEditor from '../LogsQueryEditor/LogsQueryEditor';
 import NewMetricsQueryEditor from '../MetricsQueryEditor/MetricsQueryEditor';
-import TracesQueryEditor from '../TracesQueryEditor';
+import TracesQueryEditor from '../TracesQueryEditor/TracesQueryEditor';
 
 import { QueryHeader } from './QueryHeader';
 import usePreparedQuery from './usePreparedQuery';
@@ -97,26 +92,14 @@ const QueryEditor = ({
         onClose={() => setAzureLogsCheatSheetModalOpen(false)}
         onChange={(a) => onChange({ ...a, queryType: AzureQueryType.LogAnalytics })}
       />
-      <div className={css({ display: 'flex', alignItems: 'center' })}>
-        <QueryHeader query={query} onQueryChange={onQueryChange} />
-        {query.queryType === AzureQueryType.LogAnalytics && (
-          <Button
-            aria-label="Azure logs kick start your query button"
-            variant="secondary"
-            size="sm"
-            onClick={() => {
-              setAzureLogsCheatSheetModalOpen((prevValue) => !prevValue);
-
-              reportInteraction('grafana_azure_logs_query_patterns_opened', {
-                version: 'v2',
-                editorMode: query.azureLogAnalytics,
-              });
-            }}
-          >
-            Kick start your query
-          </Button>
-        )}
-      </div>
+      <QueryHeader
+        query={query}
+        onQueryChange={onQueryChange}
+        setAzureLogsCheatSheetModalOpen={setAzureLogsCheatSheetModalOpen}
+        onRunQuery={baseOnRunQuery}
+        data={data}
+        app={app}
+      />
       <EditorForQueryType
         data={data}
         subscriptionId={subscriptionId}
@@ -124,15 +107,21 @@ const QueryEditor = ({
         query={query}
         datasource={datasource}
         onChange={onQueryChange}
+        onQueryChange={onChange}
         variableOptionGroup={variableOptionGroup}
         setError={setError}
         range={range}
       />
-
       {errorMessage && (
         <>
           <Space v={2} />
-          <Alert severity="error" title="An error occurred while requesting metadata from Azure Monitor">
+          <Alert
+            severity="error"
+            title={t(
+              'components.query-editor.alert-error-occurred',
+              'An error occurred while requesting metadata from Azure Monitor'
+            )}
+          >
             {errorMessage instanceof Error ? errorMessage.message : errorMessage}
           </Alert>
         </>
@@ -146,6 +135,8 @@ interface EditorForQueryTypeProps extends Omit<AzureMonitorQueryEditorProps, 'on
   basicLogsEnabled: boolean;
   variableOptionGroup: { label: string; options: AzureMonitorOption[] };
   setError: (source: string, error: AzureMonitorErrorish | undefined) => void;
+  // Used to update the query without running it
+  onQueryChange: (newQuery: AzureMonitorQuery) => void;
 }
 
 const EditorForQueryType = ({
@@ -157,6 +148,7 @@ const EditorForQueryType = ({
   variableOptionGroup,
   onChange,
   setError,
+  onQueryChange,
   range,
 }: EditorForQueryTypeProps) => {
   switch (query.queryType) {
@@ -184,6 +176,7 @@ const EditorForQueryType = ({
           variableOptionGroup={variableOptionGroup}
           setError={setError}
           timeRange={range}
+          onQueryChange={onQueryChange}
         />
       );
 
@@ -216,18 +209,19 @@ const EditorForQueryType = ({
     default:
       const type = query.queryType as unknown;
       return (
-        <Alert title="Unknown query type">
+        <Alert title={t('components.editor-for-query-type.title-unknown-query-type', 'Unknown query type')}>
           {(type === 'Application Insights' || type === 'Insights Analytics') && (
             <>
-              {type} was deprecated in Grafana 9. See the{' '}
-              <a
-                href="https://grafana.com/docs/grafana/latest/datasources/azure-monitor/#application-insights-and-insights-analytics-removed"
-                target="_blank"
-                rel="noreferrer"
-              >
-                deprecation notice
-              </a>{' '}
-              to get more information about how to migrate your queries. This is the current query definition:
+              <Trans i18nKey="components.editor-for-query-type.body-unknown-query-type">
+                {{ type }} was deprecated in Grafana 9. See the{' '}
+                <TextLink
+                  href="https://grafana.com/docs/grafana/latest/datasources/azure-monitor/#application-insights-and-insights-analytics-removed"
+                  external
+                >
+                  deprecation notice
+                </TextLink>{' '}
+                to get more information about how to migrate your queries. This is the current query definition:
+              </Trans>
               <CodeEditor height="200px" readOnly language="json" value={JSON.stringify(query, null, 4)} />
             </>
           )}
@@ -238,19 +232,21 @@ const EditorForQueryType = ({
 
 const UserAuthAlert = () => {
   return (
-    <Alert title="Unsupported authentication provider" data-testid={selectors.components.queryEditor.userAuthAlert}>
-      <>
+    <Alert
+      title={t('components.user-auth-alert.title-unsupported-auth', 'Unsupported authentication provider')}
+      data-testid={selectors.components.queryEditor.userAuthAlert}
+    >
+      <Trans i18nKey="components.user-auth-alert.body-unsupported-auth">
         Usage of this data source requires you to be authenticated via Azure Entra (formerly Azure Active Directory).
         Please review the{' '}
-        <a
+        <TextLink
           href="https://grafana.com/docs/grafana/latest/datasources/azure-monitor/#configure-current-user-authentication"
-          target="_blank"
-          rel="noreferrer"
+          external
         >
           documentation
-        </a>{' '}
+        </TextLink>{' '}
         for more information.
-      </>
+      </Trans>
     </Alert>
   );
 };
@@ -258,21 +254,23 @@ const UserAuthAlert = () => {
 const UserAuthFallbackAlert = () => {
   return (
     <Alert
-      title="No fallback credentials available"
+      title={t(
+        'components.user-auth-fallback-alert.title-no-fallback-credentials',
+        'No fallback credentials available'
+      )}
       data-testid={selectors.components.queryEditor.userAuthFallbackAlert}
     >
-      <>
+      <Trans i18nKey="components.user-auth-fallback-alert.body-no-fallback-credentials">
         Data source backend features (such as alerting) require service credentials to function. This data source is
         configured without service credential fallback, or the fallback functionality is disabled. Please review the{' '}
-        <a
+        <TextLink
           href="https://grafana.com/docs/grafana/latest/datasources/azure-monitor/#configure-current-user-authentication"
-          target="_blank"
-          rel="noreferrer"
+          external
         >
           documentation
-        </a>{' '}
+        </TextLink>{' '}
         for more information.
-      </>
+      </Trans>
     </Alert>
   );
 };
