@@ -4,8 +4,6 @@ import { DataQueryRequest, dateTime, LoadingState } from '@grafana/data';
 import { config } from '@grafana/runtime';
 
 import { LokiDatasource } from './datasource';
-import * as logsTimeSplit from './logsTimeSplitting';
-import * as metricTimeSplit from './metricTimeSplitting';
 import { createLokiDatasource } from './mocks/datasource';
 import { getMockFrames } from './mocks/frames';
 import { runSplitQuery } from './querySplitting';
@@ -282,18 +280,12 @@ describe('runSplitQuery()', () => {
 
   describe('Hidden and empty queries', () => {
     beforeAll(() => {
-      jest.spyOn(logsTimeSplit, 'splitTimeRange').mockReturnValue([]);
-      jest.spyOn(metricTimeSplit, 'splitTimeRange').mockReturnValue([]);
       jest.useFakeTimers().setSystemTime(new Date('Wed May 17 2023 17:20:12 GMT+0200'));
     });
     beforeEach(() => {
-      jest.mocked(logsTimeSplit.splitTimeRange).mockClear();
-      jest.mocked(logsTimeSplit.splitTimeRange).mockClear();
       jest.mocked(trackGroupedQueries).mockClear();
     });
     afterAll(() => {
-      jest.mocked(logsTimeSplit.splitTimeRange).mockRestore();
-      jest.mocked(metricTimeSplit.splitTimeRange).mockRestore();
       jest.useRealTimers();
     });
     test('Ignores hidden queries', async () => {
@@ -302,8 +294,6 @@ describe('runSplitQuery()', () => {
         { expr: '{a="b"}', refId: 'B' },
       ]);
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
-        expect(logsTimeSplit.splitTimeRange).toHaveBeenCalled();
-        expect(metricTimeSplit.splitTimeRange).not.toHaveBeenCalled();
         expect(trackGroupedQueries).toHaveBeenCalledTimes(1);
         expect(trackGroupedQueries).toHaveBeenCalledWith(
           {
@@ -313,9 +303,10 @@ describe('runSplitQuery()', () => {
           },
           [
             {
-              partition: [],
+              partition: expect.any(Array),
               request: {
                 ...request,
+                // Only includes queries that are not hidden
                 targets: request.targets.filter((query) => !query.hide),
               },
             },
@@ -331,8 +322,6 @@ describe('runSplitQuery()', () => {
         { expr: '', refId: 'B' },
       ]);
       await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
-        expect(logsTimeSplit.splitTimeRange).not.toHaveBeenCalled();
-        expect(metricTimeSplit.splitTimeRange).toHaveBeenCalled();
         expect(trackGroupedQueries).toHaveBeenCalledTimes(1);
         expect(trackGroupedQueries).toHaveBeenCalledWith(
           {
@@ -342,9 +331,10 @@ describe('runSplitQuery()', () => {
           },
           [
             {
-              partition: [],
+              partition: expect.any(Array),
               request: {
                 ...request,
+                // Only includes queries with an expression
                 targets: request.targets.filter((query) => query.expr),
               },
             },
